function numOfStableSteps = simulate(theta_init, x_init, g, m_c, m_p, ...
    l, h_max, r_max, tau, simulationTime, fisController, numberOfInputs)
    
    % simulation parameters:
    numTimeSteps = simulationTime/tau;
    
    % initial values:
    angle_theta = theta_init;
    angle_velo = 0;
    pos_x = x_init;
    pos_velo = 0;

    numOfStableSteps = 0;
    for t=1:numTimeSteps    
        % compute response:
        %F = myFuzzyController(pos_x, angle_theta, fisController);
        %F = myFuzzyControllerThetaThetaDot(angle_theta, angle_velo, fisController);
        %F = myFuzzyControllerThetaThetaDotAndX(angle_theta, angle_velo, pos_x, fisController);
        switch numberOfInputs
            case 2
                F = myFuzzyController_2inputs(angle_theta, angle_velo, fisController);
            case 3
                F = myFuzzyController_3inputs(angle_theta, angle_velo, pos_x, fisController);
        end

        angle_acc = getAngleAccelaration(g, angle_theta, angle_velo, F, m_p, m_c, l);
        pos_acc = getPosAccelaration(F, m_p, l, angle_velo, angle_theta, angle_acc, m_c);

        % integration step of Euler method:
        angle_theta = angle_theta + tau.*angle_velo;
        angle_velo = angle_velo + tau.*angle_acc;
        pos_x = pos_x + tau.*pos_velo;
        pos_velo = pos_velo + tau.*pos_acc;

        % check whether current state is feasible and stop if not:
        if (pos_x < -h_max || pos_x > h_max || ...
                angle_theta < -r_max || angle_theta > r_max)
            fprintf('Current state of pole not stable after %e seconds\n', t*tau);
            fprintf('   x_%d = %e; theta_%d = %e\n', t, pos_x, t, angle_theta);
            break;
        end
        
        numOfStableSteps = numOfStableSteps + 1;
       
        if mod(t,100) == 0
            fprintf('iteration %d\n', t);
        end
        
        subplot(4,1,1);
        plot(t*tau,pos_x,'xb');
        hold all;
        subplot(4,1,2);
        plot(t*tau,pos_velo,'oy');
        hold all;
        subplot(4,1,3);
        plot(t*tau,angle_theta,'xr');
        hold all;
        subplot(4,1,4);
        plot(t*tau,angle_velo,'oy');
        hold all;
        
    end

end