% model parameters:
theta_init = 0.1; % initial angle of pole (in radians)
x_init = 0.2;     % initial cart position (in m)
g = 9.81;       % gravitational acceleration (in m/s^2)
m_c = 1;        % mass of cart (in kg)
m_p = 0.1;      % mass of pole (in kg)
l = 0.5;        % distance from pivot to pole center (length = 2*l)
h_max = 100;    % maximal deviation in cart position (in m)
r_max = pi/2;   % maximal deviation in pole angle (in radians=approx. 12)
tau = 0.02;     % time step (in s)

numberOfInputs = 2;

% read controller from file:
switch numberOfInputs
    case 2
        myController = readfis('controller_2inputs');
    case 3
        myController = readfis('controller_3inputs');
end
    

% simulation parameters:
simulationTime = 60; % (in s)

figure(1); % for plotting

numOfStableSteps = simulate(theta_init, x_init, g, m_c, m_p, l, ...
    h_max, r_max, tau, simulationTime, myController, numberOfInputs);

% plotting:
subplot(4,1,1);
title('position');
hold off;
subplot(4,1,2);
title('dx/dt');
hold off;
subplot(4,1,3);
title('angle');
hold off;
subplot(4,1,4);
title('d\theta/dt');
hold off;


